# Changelog

## 1.1.8 (2020-12-04)
- [Fix] removed pyparsing dep altogether; unnecessary

## 1.1.7 (2020-12-04)
- [Fix] add retry logic to HTTP requesting
- [Fix] add pyparsing dependency for Jenkins pipelines

## 1.1.6 (2020-12-03)
- [Fix] remove useless dependency

## 1.1.5 (2020-11-25)
- [Feature] Filtering for ls-related commands
- [Feature] Progress bar at project upload
- [Feature] Add Bamboo pipeline example
- [Fix] Global SLA are not displayed in Junit report

## 1.1.4 (2020-09-25)
- [Feature] Capability to manage self signed certificate
- [Feature] .nlignore files allow you to specify yaml files not to upload (ex: .gitlab-ci.yaml)
- [Feature] Add AWS pipeline example
- [Feature] Add 'cur' pseudonym support to logs-url command

## 1.1.0 (2020-08-11)
- [Feature] Workspace command and support workspaces at login
- [Feature] Fastfail command and the jenkins example for fastfail
- [Improvement] Jenkins pipeline example and many other small improvements
- [Improvement] Better error message for bad NL url
- [Fix] Handling of pagination by API for ls subcommand
- [Fix] Support "between" threshold in SLA</li></ul>

## 1.0.1 (2020-06-25)
- [Fix] Set required versions for setup
- [Fix] error when displaying results at the end of the test

## 1.0.0 (2020-05-14)
Initial version with commands and sub-commands

## 0.4.6 (2020-05-09)
Experimental version
